==> cordial-0.22.tar.gz: cordial-0.22/setup.py <==
from setuptools import setup

setup(
  name = 'cordial',         
  packages = ['cordial'],   # Chose the same as "name"
  version = '0.22',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'comprehensive recommender systems',   # Give a short description about your library
  author = 'Vagif Aliyev',                   # Type in your name
  author_email = 'vagal2003@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Vagif12/cordial',   # Provide either the link to your github or to your website
  keywords = ['machine learning', 'recommender systems', 'automation'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pandas',
          'numpy',
          'networkx',
          'scikit-learn'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> cordial-0.222.tar.gz: cordial-0.222/setup.py <==
from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
  name = 'cordial',         
  packages = ['cordial'],   # Chose the same as "name"
  version = '0.222',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'comprehensive recommender systems',   # Give a short description about your library
  author = 'Vagif Aliyev',                   # Type in your name
  long_description=long_description,
  long_description_content_type="text/markdown",
  author_email = 'vagal2003@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Vagif12/cordial',   # Provide either the link to your github or to your website
  keywords = ['machine learning', 'recommender systems', 'automation'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pandas',
          'numpy',
          'networkx',
          'scikit-learn'
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
